sumo package
=============

Module contents
---------------

.. automodule:: sumo
    :members:
    :undoc-members:
    :show-inheritance:

Subpackages
-----------

.. toctree::

    sumo.cli
    sumo.electronic_structure
    sumo.phonon
    sumo.plotting
    sumo.symmetry
